# HuggingGAN / Geniverse / etc
### Created by Victor & Javi
The project combines a library ecosystem for generative and creative IA with specific tools.

![Alt text](./media/MVP-1.png?raw=true "mockup 1")


Forks are integrated into this repo using [submodules](https://gist.github.com/gitaarik/8735255). To properly load the forks, the following command must be executed:
```python
git submodule init
```
